# AdviserResultResponseResultReportPipelineBoots

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  |
**configuration** | **object** |  |
**unit_run** | **bool** | Flag set to true if the pipeline unit was run during the resolution process  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

